/**************************************************************************//**
*   @file   main.c
*   @brief  System validation program
*   @author ACostina (adrian.costina@analog.com)
*
*******************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 1766
******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <altera_avalon_pio_regs.h>

#include "ced1z.h"
#include "system.h"
#include "AD7401.h"

/*****************************************************************************/
/************************ Variables Definitions ******************************/
/*****************************************************************************/

volatile int *txData              	= (volatile int *) 0x4e0000;	// address of the start of the memory used for storing samples
volatile int size         			= 0;                        	// used for the request of number of samples
volatile int startAcquisition    	= 0;                        	// starts one acquisition cycle

/*****************************************************************************/
/************************ Functions Definitions ******************************/
/*****************************************************************************/

int main(void)
{
	// Configure CED1Z voltages
    configure_vio_fpga(VIO_FPGA_3_3V);
    configure_vara(VARA_2_5V);
    configure_vard(VARD_3_3V);
    configure_3V3D(V3V3D_3_3V);
    //activate the programmable power pins
    init_power(N15_EN|N5VA_EN|P5VA_SD|VARA_SD|VARD_SD|P5VD_SD|P3VD_SD); //12V selected
    usleep(500000);         //waiting for the EvalBoard to initialize

	//declare TCL related variables
    volatile int *startAcquisitionTCL           = (int *)0x4a0000;
    volatile int *transferCompleteTCL           = (int *)0x4a0004;
    volatile int *processingDataTCL             = (int *)0x4a0008;
    volatile int *operationCompleteTCL          = (int *)0x4a000C;
    volatile int *startAcqPointer               = (int *)0x4a0014;
	volatile int *commandWord					= (int *)0x4a0018;

	*startAcquisitionTCL        = 0;
    *startAcqPointer           	= &startAcquisition;
    //clear all LEDs
    IOWR_ALTERA_AVALON_PIO_DATA (LEDS_BASE, 0x00);

	size = MEMORY_LINE_SIZE * MAX_MEMORY_LINES;
	AD7401_Reset();
	usleep(13000);

    IOWR_ALTERA_AVALON_PIO_DATA (LEDS_BASE, 0x01);

	// run program
	while(1)
	{
		*startAcquisitionTCL            = 0;
		*transferCompleteTCL            = 0;
		*processingDataTCL              = 0;
		*operationCompleteTCL           = 0;

		IOWR_ALTERA_AVALON_PIO_DATA (LEDS_BASE, 0x01);

		*startAcqPointer			= &startAcquisition;

		if(startAcquisition)
		{
			*startAcquisitionTCL            = 0;
			*transferCompleteTCL            = 0;
			*processingDataTCL              = 0;
			*operationCompleteTCL           = 0;
			//reset the PC transfer status variables
			//signal the start of the data acquisition
			IOWR_ALTERA_AVALON_PIO_DATA (LEDS_BASE, 0x03);

			AD7401_StartAcquisition(size, (int)txData);

			while(!( AD7401_ReadStatus() & 0x00000001));

			*startAcquisitionTCL            = 1;

			IOWR_ALTERA_AVALON_PIO_DATA (LEDS_BASE, 0x05);
			while (*operationCompleteTCL == 0);

			startAcquisition			= 0;
		}
	}
}
